% Inizializzazione
clc;
clear;
close all;

[imgName, path] = uigetfile('*.jpg;*.bmp;*.png;*.tiff;*.tif;*.jpeg', 'Pick an image file');

img = imread([path imgName]);

dim = size(size(img));
if dim(2) == 3
    
    subplot(1,2,1);
    imshow(img);
    
    %Split into RGB Channels
    Red = img(:,:,1);
    Green = img(:,:,2);
    Blue = img(:,:,3);
    
    %%ISTOGRAMMA
    %sintassi generale: h = imhist(f, b)
    %dove:
    % - h : istogramma
    % - f : img orig
    % - b : n. di bins (default =256)
    
    %Get histValues for each channel
    [yRed, ~] = imhist(Red);
    [yGreen, ~] = imhist(Green);
    [yBlue, x] = imhist(Blue);
    
    subplot(1,2,2);
    %Plot them together in one plot
    plot(x, yRed, 'Red', x, yGreen, 'Green', x, yBlue, 'Blue');
    axis tight;
    img_gray = rgb2gray(img);
else
    img_gray = img;
end

figure;
subplot(3,3,1);
imshow(img_gray);
title('Original');

%plot:

subplot(3,3,2);
im_hist =imhist(img_gray);
plot(im_hist);
axis tight;
title('Histogram on Original Image');
xlabel('l.d.g.');
ylabel('#pixels');

%CDF
CDF = cumsum(im_hist); %transformation function
CDF = CDF / max(CDF);

subplot(3,3,3);
plot(CDF);
axis tight;
title('CDF ORIG');
xlabel('l.d.g.');
ylabel('#pixels <= g');

%%CONTRAST STRETCHING con min e max al 3 e 97 percentile
%Sintassi generale: J = imadjust(I,[low_in; high_in],[low_out; high_out],gamma)

img_CS = imadjust(img_gray, stretchlim(img_gray, [0.03, 0.97]), [], 0.5);

subplot(3,3,4);
imshow(img_CS);
title('Contrast Stretching');


subplot(3,3,5);
hist_CS = imhist(img_CS);
plot(hist_CS);
axis tight;
title('Histogram after CS');
xlabel('l.d.g.');
ylabel('#pixels <= g');
 
%CDF 
CDF_CS = cumsum(hist_CS); %transformation function
CDF_CS = CDF_CS / max(CDF_CS);
 
subplot(3,3,6);
plot(CDF_CS);
axis tight;
title('CDF after Contrast Stretching');
xlabel('l.d.g.');
ylabel('#pixels <= g');


%%EQUALIZZAZIONE
img_EQUAL = histeq(img_gray);

subplot(3,3,7);
imshow(img_EQUAL);
title('Equalization');

subplot(3,3,8);
hist_EQ = imhist(img_EQUAL);
plot(hist_EQ);
axis tight;
title('istogramma EQUAL');

%CDF 
CDF_EQ = cumsum(hist_EQ); %transformation function
CDF_EQ = CDF_EQ / max(CDF_EQ);

subplot(3,3,9);
plot(CDF_EQ);
axis tight;
title('CDF after Equalization');











