function remapped = colorHistogramMatching2(Input, Target)

%Split into RGB Channels
Red = Input(:,:,1);
Green = Input(:,:,2);
Blue = Input(:,:,3);

%Histograms & CDFs
[~, CDF_R] = HISTandCDF(Red);
[~, CDF_G] = HISTandCDF(Green);
[~, CDF_B] = HISTandCDF(Blue);

%Target Image:
%Split into RGB Channels
RedT = Target(:,:,1);
GreenT = Target(:,:,2);
BlueT = Target(:,:,3);

%Histograms & CDFs
[~, CDF_RT] = HISTandCDF(RedT);
[~, CDF_GT] = HISTandCDF(GreenT);
[~, CDF_BT] = HISTandCDF(BlueT);
    
%build LUTs
LUT_R = buildLUT(CDF_RT, CDF_R);
LUT_G = buildLUT(CDF_GT, CDF_G);
LUT_B = buildLUT(CDF_BT, CDF_B);


%Histogram Matching
remapped = zeros(size(Input));
remapped(:,:,1) = LUT_R(Red+1);
remapped(:,:,2) = LUT_G(Green+1);
remapped(:,:,3) = LUT_B(Blue+1);

%Visualizations
remapped = uint8(remapped);
figure;
subplot(1,3,1);
imshow(Input);
title('Input image');
 
subplot(1,3,2);
imshow(Target);
title('Target Image');

subplot(1,3,3);
imshow(remapped);
title('Remapped Image');
end

function LUT = buildLUT(CDF_T, CDF_C)
LUT = zeros(256,1);
g_T = 0;
for g_I=0:255
    while CDF_T(g_T+1)< CDF_C(g_I+1) & g_T < 255
        g_T = g_T + 1;
    end
    LUT(g_I+1) = g_T;
end
end


function [hist_I, CDF_I] = HISTandCDF(img)
hist_I =imhist(img);

%Color CDF
CDF_I = cumsum(hist_I); %transformation function
CDF_I = CDF_I / max(CDF_I);
end

